@@ -8,12 +8,13 @@
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -483,6 +484,7 @@ void xa_clean_archive_structure (XArchive *archive)
 	g_free(archive->path[0]);
 	g_free(archive->path[1]);
 	g_free(archive->path[2]);
+	g_free(archive->destination_path);
 	g_free(archive->extraction_dir);
 	g_free(archive->password);
 	g_free(archive->child_dir);
@@ -493,15 +495,22 @@ void xa_clean_archive_structure (XArchive *archive)
 gboolean xa_create_working_directory (XArchive *archive)
 {
 	gchar *tmp_dir;
-	gchar *value, *value_local;
+	gchar *value;
 
 	if (archive->working_dir != NULL)
 		return TRUE;
 
 	value = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->combo_prefered_temp_dir));
-	value_local = g_filename_from_utf8(value, -1, NULL, NULL, NULL);
-	tmp_dir = g_strconcat(value_local, "/xa-XXXXXX", NULL);
-	g_free(value_local);
+
+	if (value && *value)
+	{
+		gchar *value_local = g_filename_from_utf8(value, -1, NULL, NULL, NULL);
+		tmp_dir = g_strconcat(value_local, "/xa-XXXXXX", NULL);
+		g_free(value_local);
+	}
+	else
+		tmp_dir = g_strdup("");
+
 	g_free(value);
 
 	if (!g_mkdtemp(tmp_dir))
