@@ -8,12 +8,13 @@
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301 USA.
  */
 
 #include <string.h>
@@ -82,7 +83,7 @@ static void xa_cpio_parse_output (gchar *line, XArchive *archive)
 	/* time */
 	if (((char *) item[2])[9] == ':')
 	{
-		strncpy(time, ((char *) item[2]) + 7, 5);
+		memcpy(time, item[2] + 7, 5);
 		time[5] = 0;
 	}
 	else
