@@ -3,17 +3,18 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License,or
- *  (at your option)any later version.
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not,write to the Free Software
- *  Foundation,Inc.,59 Temple Street #330,Boston,MA 02111-1307,USA.
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301 USA.
  */
 
 #include <errno.h>
@@ -433,8 +434,6 @@ Extract_dialog_data *xa_create_extract_dialog()
 
 void xa_set_extract_dialog_options(Extract_dialog_data *dialog_data,gint selected,XArchive *archive)
 {
-	gchar *archive_dir = NULL;
-
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->check_save_geometry))&& prefs_window->extract_dialog[0] != -1)
 		gtk_window_set_default_size (GTK_WINDOW(dialog_data->dialog1),prefs_window->extract_dialog[0],prefs_window->extract_dialog[1]);
 	else
@@ -463,19 +462,24 @@ void xa_set_extract_dialog_options(Extract_dialog_data *dialog_data,gint selecte
 	gtk_widget_set_sensitive(dialog_data->update, archive->can_update[0]);
 	gtk_widget_set_sensitive(dialog_data->fresh, archive->can_freshen[0]);
 
-	if (!*gtk_entry_get_text(GTK_ENTRY(dialog_data->destination_path_entry)))
+	if (!archive->destination_path)
 	{
-		archive_dir = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->combo_prefered_extract_dir));
-		if (archive_dir == NULL)
+		gchar *archive_dir = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->combo_prefered_extract_dir));
+
+		if (!archive_dir || !*archive_dir)
 		{
-			gchar *archive_dir_utf8 = g_filename_display_name(archive->path[0]);
+			gchar *archive_dir_utf8;
+
+			g_free(archive_dir);
+			archive_dir_utf8 = g_filename_display_name(archive->path[0]);
 			archive_dir = xa_remove_level_from_path(archive_dir_utf8);
 			g_free(archive_dir_utf8);
 		}
-		gtk_entry_set_text (GTK_ENTRY(dialog_data->destination_path_entry),archive_dir);
-	}
-	g_free(archive_dir);
 
+		archive->destination_path = g_strdup(archive_dir);
+		g_free(archive_dir);
+	}
+	gtk_entry_set_text(GTK_ENTRY(dialog_data->destination_path_entry), archive->destination_path);
 	gtk_entry_set_text(GTK_ENTRY(dialog_data->password_entry), archive->password ? archive->password : "");
 
 	gtk_widget_set_sensitive(label_password, archive->has_password);
@@ -501,7 +505,9 @@ void xa_parse_extract_dialog_options (XArchive *archive,Extract_dialog_data *dia
 			break;
 
 			case GTK_RESPONSE_OK:
-			destination_path = g_filename_from_utf8(gtk_entry_get_text(GTK_ENTRY(dialog_data->destination_path_entry)), -1, NULL, NULL, NULL);
+			g_free(archive->destination_path);
+			archive->destination_path = g_strdup(gtk_entry_get_text(GTK_ENTRY(dialog_data->destination_path_entry)));
+			destination_path = g_filename_from_utf8(archive->destination_path, -1, NULL, NULL, NULL);
 			g_free(archive->extraction_dir);
 			archive->extraction_dir = xa_escape_bad_chars(destination_path, ESCAPES);
 
