@@ -8,12 +8,13 @@
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -626,6 +627,18 @@ static void xa_check_available_archivers ()
 	else
 		path = g_find_program_in_path("unrar");
 
+	if (path)
+	{
+		xa_rar_check_version(path);
+
+		if (!rar_version)
+		{
+			/* reject incompatible program */
+			g_free(path);
+			path = NULL;
+		}
+	}
+
 	standard = (path != NULL);
 
 	if (!standard)
@@ -653,7 +666,7 @@ static void xa_check_available_archivers ()
 		archiver[type].type = g_slist_append(archiver[type].type, "rar");
 		archiver[type].glob = g_slist_append(archiver[type].glob, "*.rar");
 
-		if (!standard || (xa_rar_check_version(path) == 5))
+		if (!standard || (rar_version >= 5))
 		{
 			archiver[type].type = g_slist_append(archiver[type].type, "rar5");
 			archiver[type].glob = g_slist_append(archiver[type].glob, " .rar");
@@ -1003,6 +1016,14 @@ static XArchive *xa_init_structure_from_cmd_line (char *filename)
 	return archive;
 }
 
+static void xa_cmd_line_error (const char *argv1, const gchar *header)
+{
+	if (argv1)
+		xa_show_message_dialog(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, header, _("Can't open the archive!\n"));
+	else
+		xa_show_message_dialog(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, header, _("You missed the archive name!\n"));
+}
+
 int main (int argc, char **argv)
 {
 	GError *cli_error = NULL;
@@ -1075,9 +1096,7 @@ int main (int argc, char **argv)
 
 			if (!archive)
 			{
-				if (!argv[1])
-					xa_show_message_dialog(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Can't extract files from the archive:"), _("You missed the archive name!\n"));
-
+				xa_cmd_line_error(argv[1], _("Can't extract files from the archive:"));
 				goto leave;
 			}
 
@@ -1103,7 +1122,7 @@ int main (int argc, char **argv)
 				current_dir = g_get_current_dir();
 
 				if (xa_has_containing_directory(archive))
-					extraction_dir = xa_escape_bad_chars(current_dir, ESCAPES);
+					extraction_dir = g_strdup(current_dir);
 				else
 				{
 					extraction_dir = xa_create_containing_directory(archive, current_dir);
@@ -1133,9 +1152,7 @@ int main (int argc, char **argv)
 		{
 			if (!archive)
 			{
-				if (!argv[1])
-					xa_show_message_dialog(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Can't extract files from the archive:"), _("You missed the archive name!\n"));
-
+				xa_cmd_line_error(argv[1], _("Can't extract files from the archive:"));
 				goto leave;
 			}
 
@@ -1207,9 +1224,7 @@ int main (int argc, char **argv)
 		{
 			if (!archive)
 			{
-				if (!argv[1])
-					xa_show_message_dialog(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Can't add files to the archive:"), _("You missed the archive name!\n"));
-
+				xa_cmd_line_error(argv[1], _("Can't add files to the archive:"));
 				goto leave;
 			}
 			if (!archive->can_add)
