@@ -3,17 +3,18 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License,or
+ *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not,write to the Free Software
- *  Foundation,Inc.,59 Temple Street #330,Boston,MA 02111-1307,USA.
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -485,8 +486,8 @@ static gchar *xa_get_statusbar_message (guint64 total_size, gint n_elem, gint di
 
 static void xa_set_environment (gpointer display)
 {
-	g_setenv("DISPLAY", display, TRUE);
-	g_free(display);
+	if (!g_getenv("WAYLAND_DISPLAY"))
+		g_setenv("DISPLAY", display, TRUE);
 }
 
 static void xa_determine_program_to_run (gchar *file)
@@ -1155,7 +1156,7 @@ void xa_list_archive (GtkMenuItem *menuitem,gpointer data)
 	gint idx;
 	FILE *stream;
 	GtkWidget *save = NULL;
-	gchar *t, *_filename, *filename, *filename_plus, *filename_plus_utf8, *pref_path, *pref_path_local;
+	gchar *t, *_filename, *filename, *filename_plus, *filename_plus_utf8, *pref_path, *pref_path_local = NULL;
 	int response;
 	struct stat my_stat;
 	guint64 file_size;
@@ -1193,8 +1194,11 @@ void xa_list_archive (GtkMenuItem *menuitem,gpointer data)
 	filename = NULL;
 
 	pref_path = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->combo_prefered_extract_dir));
-	pref_path_local = g_filename_from_utf8(pref_path, -1, NULL, NULL, NULL);
+
+	if (pref_path && *pref_path)
+		pref_path_local = g_filename_from_utf8(pref_path, -1, NULL, NULL, NULL);
 	g_free(pref_path);
+
 	if (current_open_directory || pref_path_local)
 		gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(save), pref_path_local ? pref_path_local : current_open_directory);
 	g_free(pref_path_local);
@@ -1716,28 +1720,29 @@ void xa_about (GtkMenuItem *menuitem,gpointer user_data)
 		g_object_set (about,
 			"program-name", PACKAGE_NAME,
 			"version",PACKAGE_VERSION,
-			"copyright","Copyright \xC2\xA9 " COPYRIGHT_YEAR " " COPYRIGHT_HOLDER,
+			"copyright","Copyright \xC2\xA9 " COPYRIGHT_YEAR " " COPYRIGHT_HOLDER "\n"
+			            "Copyright \xC2\xA9 " MAINTAINER_YEAR " " MAINTAINER,
 			"comments",_("A GTK+ only lightweight archive manager"),
 			"authors",authors,
 			"documenters",documenters,
 			"translator_credits",_("translator-credits"),
 			"logo_icon_name","xarchiver",
 			"website","https://wiki.github.com/ib/xarchiver",
-			"license","Copyright \xC2\xA9 " COPYRIGHT_YEAR " " COPYRIGHT_HOLDER " - Colossus <colossus73@gmail.com>\n\n"
-					"This is free software; you can redistribute it and/or\n"
-					"modify it under the terms of the GNU Library General Public License as\n"
-					"published by the Free Software Foundation; either version 2 of the\n"
-					"License,or (at your option) any later version.\n"
+			"license","Copyright \xC2\xA9 " COPYRIGHT_YEAR " " COPYRIGHT_HOLDER " - Colossus <colossus73@gmail.com>\n"
+			          "Copyright \xC2\xA9 " MAINTAINER_YEAR " " MAINTAINER "\n\n"
+					"This program is free software; you can redistribute it and/or modify it\n"
+					"under the terms of the GNU General Public License as published by the\n"
+					"Free Software Foundation; either version 2 of the License, or (at your option)\n"
+					"any later version.\n"
 					"\n"
-					"This software is distributed in the hope that it will be useful,\n"
-					"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-					"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU\n"
-					"Library General Public License for more details.\n"
+					"This program is distributed in the hope that it will be useful, but WITHOUT\n"
+					"ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n"
+					"or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public\n"
+					"License for more details.\n"
 					"\n"
-					"You should have received a copy of the GNU Library General Public\n"
-					"License along with the Gnome Library; see the file COPYING.LIB.  If not,\n"
-					"write to the Free Software Foundation,Inc.,59 Temple Place - Suite 330,\n"
-					"Boston,MA 02111-1307,USA.\n",
+					"You should have received a copy of the GNU General Public License\n"
+					"along with this program; if not, write to the Free Software Foundation, Inc.,\n"
+					"51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.",
 		      NULL);
 	}
 	gtk_dialog_run ( GTK_DIALOG(about));
@@ -1835,7 +1840,7 @@ ArchiveType xa_detect_archive_type (const gchar *filename)
 		if (magic[6] == 1)
 			xa.tag = 5;
 
-		/* a rar5 archive without rar v5 executable can't be opened */
+		/* a rar5 archive without a rar v5 compatible executable can't be opened */
 		if ((xa.tag == 5) && !g_slist_find(archiver[xa.type].tags, GUINT_TO_POINTER(xa.tag)))
 			archiver[xa.type].list = NULL;
 	}
@@ -2371,7 +2376,7 @@ gboolean xa_launch_external_program (const gchar *program, const gchar *arg)
 	GError *error = NULL;
 	gchar *program_local, *arg_local, *command_line;
 	gchar **argv;
-	GdkScreen *screen;
+	GdkDisplay *display;
 	gboolean success = TRUE;
 
 	if (g_utf8_validate(program, -1, NULL))
@@ -2390,8 +2395,9 @@ gboolean xa_launch_external_program (const gchar *program, const gchar *arg)
 	g_free(program_local);
 	g_free(arg_local);
 
-	screen = gtk_widget_get_screen (GTK_WIDGET (xa_main_window));
-	if (!GDK_COMPAT_SPAWN(NULL, argv, NULL, G_SPAWN_SEARCH_PATH, xa_set_environment, gdk_screen_make_display_name(screen), NULL, &error))
+	display = gdk_display_get_default();
+
+	if (!GDK_COMPAT_SPAWN(NULL, argv, NULL, G_SPAWN_SEARCH_PATH, xa_set_environment, (gpointer) gdk_display_get_name(display), NULL, &error))
 	{
 		message = gtk_message_dialog_new (GTK_WINDOW (xa_main_window),
 										GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
